==> genometools-1.3.4.tar.gz: genometools-1.3.4/src/gth/txt_sa_visitor.h <==
/*
  Copyright (c) 2008-2009 Gordon Gremme <gremme@zbh.uni-hamburg.de>
  Copyright (c) 2008      Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef TXT_SA_VISITOR_H
#define TXT_SA_VISITOR_H

#include "gth/sa_visitor.h"
#include "gth/input.h"

/* implements the ``spliced alignment visitor'' interface */
typedef struct GthTxtSAVisitor GthTxtSAVisitor;

const GthSAVisitorClass* gth_txt_sa_visitor_class(void);
GthSAVisitor*            gth_txt_sa_visitor_new(GthInput*,
                                                bool gs2out,
                                                unsigned long minintronlength,
                                                unsigned long widthforgenpos,
                                                unsigned long showintronmaxlen,
                                                unsigned long translationtable,
                                                bool showseqnums,
                                                GtFile *outfp);

#endif

==> genometools_1.5.2.orig.tar.gz: genometools-1.5.2/src/gth/txt_sa_visitor.h <==
/*
  Copyright (c) 2008-2009 Gordon Gremme <gordon@gremme.org>
  Copyright (c) 2008      Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef TXT_SA_VISITOR_H
#define TXT_SA_VISITOR_H

#include "gth/sa_visitor.h"
#include "gth/input.h"

/* implements the ``spliced alignment visitor'' interface */
typedef struct GthTxtSAVisitor GthTxtSAVisitor;

const GthSAVisitorClass* gth_txt_sa_visitor_class(void);
GthSAVisitor*            gth_txt_sa_visitor_new(GthInput*,
                                                bool gs2out,
                                                GtUword minintronlength,
                                                GtUword widthforgenpos,
                                                GtUword showintronmaxlen,
                                                GtUword translationtable,
                                                bool showseqnums,
                                                GtFile *outfp);

#endif
